# stdl
Extended Python standard library.
# Installation
Python 3.10+ is required
#### Using pip
```
pip install stdl
```
#### From source
```
pip install git+https://github.com/zigai/stdl
```
# License
[MIT License](https://github.com/zigai/stdl/blob/master/LICENSE)
